package analyzers.util;

import java.util.ArrayList;
import java.util.List;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.KeywordAnalyzer;
import org.apache.lucene.analysis.SimpleAnalyzer;
import org.apache.lucene.analysis.StopAnalyzer;
import org.apache.lucene.analysis.WhitespaceAnalyzer;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.util.Version;

import parse.FieldInfo;
import constants.AnalyzerNames;

public class AnalyzerMapper {

    public List<Analyzer> getAnalyzersForField(FieldInfo fieldInfo) {

        List<Analyzer> analyzers = new ArrayList<Analyzer>();
        analyzers.add(getAnalyzer(fieldInfo.getAnalyzer()));

        return analyzers;
    }

    private Analyzer getAnalyzer(String analyzerName) {
        if (analyzerName.equals(AnalyzerNames.WHITE_SPACE_ANALYZER)) {
            return new WhitespaceAnalyzer();
        } else if (analyzerName.equals(AnalyzerNames.SIMPLE_ANALYZER)) {
            return new SimpleAnalyzer();
        } else if (analyzerName.equals(AnalyzerNames.KEYWORD_ANALYZER)) {
            return new KeywordAnalyzer();
        } else if (analyzerName.equals(AnalyzerNames.STANDARD_ANALYZER)) {
            return new StandardAnalyzer(Version.LUCENE_30);
        } else if (analyzerName.equals(AnalyzerNames.STOP_ANALYZER)) {
            return new StopAnalyzer(Version.LUCENE_30);
        }
        return new WhitespaceAnalyzer();
    }

}
