package index.build;

import java.io.StringReader;
import java.util.List;
import java.util.Map;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.TokenStream;

import parse.FieldInfo;
import parse.LuceneConfiguration;
import value.Row;
import analyzers.util.AnalyzerMapper;

public class TokenCreator {

    private LuceneConfiguration luceneConfiguration;

    public TokenCreator(LuceneConfiguration luceneConfiguration) {
        this.luceneConfiguration = luceneConfiguration;
    }

    public TokenStream getFieldTokenStream(Row row, String fieldName) {
        String token = row.get(fieldName);
        Map<String, FieldInfo> perFieldInfo = luceneConfiguration.getPerFieldInfo();
        return createTokenStram(token, fieldName, perFieldInfo);
    }

    private TokenStream createTokenStram(String token, String fieldName, Map<String, FieldInfo> perFieldInfo) {
        FieldInfo fieldInfo = luceneConfiguration.getPerFieldInfo().get(fieldName);
        AnalyzerMapper nameAnalyzerMapper = new AnalyzerMapper();
        List<Analyzer> analyzers = nameAnalyzerMapper.getAnalyzersForField(fieldInfo);
        return applyAnalyzers(token, fieldName, analyzers);
    }

    private TokenStream applyAnalyzers(String token, String fieldName, List<Analyzer> analyzers) {
        return analyzers.get(0).tokenStream(fieldName, new StringReader(token));
    }

    public LuceneConfiguration getLuceneConfiguration() {
        return luceneConfiguration;
    }

    public void setLuceneConfiguration(LuceneConfiguration luceneConfiguration) {
        this.luceneConfiguration = luceneConfiguration;
    }

}
